@@ -290,6 +290,35 @@ class Media(ABC):
             _uids = uid if isinstance(uid, list) else [uid]
         return self.get(type=type, uid=_uids, addnew=False)
 
+    def _search_uid(self, type: str, value: str, id: str, uid=None):
+        _rtn = []
+        if uid is None or (isinstance(uid, list) and len(uid) == 0):
+            _rtn = [_u.get("uid") for _u in self._search(
+                type=type, keyval=value, id=id)]
+        else:
+            _rtn = uid if isinstance(uid, list) else [uid]
+        return _rtn
+
+    def _map_uid(self, type: str, keycol: str, uids: list, source: str = None, usesource: bool = True) -> list:
+        _source = source if source is not None else self._source
+        _source = f":{_source}" if usesource else ""
+        _table = "{}{}:{}".format(
+            self.get_table(type, "index"), _source, keycol)
+        _rtn = []
+        for _u in uids if isinstance(uids, list) else [uids]:
+            for _, _uid in self._redis.zscan_iter(name=f"{_table}:{_u}", match="*"):
+                _rtn.append(int(_uid))
+        _rtn = list(set(_rtn))
+        return _rtn
+
+    def _limit_count(self, data: list, page: int = None, count: int = None) -> list:
+        _rtn = data if isinstance(data, list) else [data]
+        _pg = 0 if page is None else int(page)
+        _cnt = 50 if count is None else int(count)
+        if len(_rtn) > ((_pg + 1) * _cnt):
+            _rtn = _rtn[(_pg * _cnt):((_pg + 1) * _cnt)]
+        return _rtn
+
     def cats(self, *args, **kwargs) -> list:
         _rtn = []
         _cat = kwargs.get("cat", None)
@@ -324,21 +353,19 @@ class Media(ABC):
             _param.update(
                 {"page": 0, "count": 500 if _count is None else _count * 10})
             _param.update({"uid": _param.get("catuid", None)})
-            _cats = self.cats(**_param)
-            _table = "{}:{}".format(self.get_table(
-                type="scats", opt="index"), "cats")
-            for _c in _cats:
-                for _a, _suid in self._redis.zscan_iter(name="{}:{}".format(_table, _c.get("uid")), match="*"):
-                    _uids.append(int(_suid))
-                break
+            _cats = [_c.get("uid") for _c in self.cats(**_param)]
+            _uids = self._map_uid(
+                type=_type, keycol="cats", uids=_cats[0], usesource=False)
+            if _uids == []:
+                return []
         _rtn = self._search(type=_type, keyval=_scat, id=_scatid,
                             uid=_uids, page=_page, count=_count)
         return _rtn
 
     def people(self, *args, **kwargs) -> list:
         _rtn = []
-        _people = kwargs.get("name", None)
-        _peopleid = kwargs.get("id", None)
+        _people = kwargs.get("people", None)
+        _peopleid = kwargs.get("peopleid", None)
         _uid = kwargs.get("uid", None)
         _page = kwargs.get("page", None)
         _count = kwargs.get("count", None)
@@ -364,54 +391,164 @@ class Media(ABC):
         _video = kwargs.get("video", None)
         _videoid = kwargs.get("videoid", None)
         _uid = kwargs.get("uid", None)
+        _people = kwargs.get("people", None)
+        _peopleid = kwargs.get("peopleid", None)
+        _peopleuid = kwargs.get("peopleuid", None)
         _exclcols = ["video", "videoid", "uid"]
+        _param = kwargs.copy()
+        for _x in _exclcols:
+            try:
+                _param.drop(_x)
+            except:
+                pass
         _page = kwargs.get("page", None)
         _count = kwargs.get("count", None)
         _type = self._source
         _uids = []
         if _uid is not None:
-            _uids = _uid if isinstance(_uid, list) else [_uid]
-        if _video is None and _videoid is None and _uid is None:
-            _param = kwargs.copy()
-            for _x in _exclcols:
-                try:
-                    _param.drop(_x)
-                except:
-                    pass
+            _uids = _uid
+        elif _people is not None or _peopleid is not None or _peopleuid is not None:
+            _puids = self._search_uid(
+                type="people", value=_people, id=_peopleid, uid=_peopleuid)
+            _uids = self._map_uid(type="people", keycol="people", uids=_puids)
+            if _uids == []:
+                return []
+
+        elif _param != {} and _video is None and _videoid is None and (_uid is None or (len(_uid) == 0 and isinstance(_uid, list))):
             _param.update(
                 {"page": 0, "count": 500 if _count is None else _count * 10})
             _param.update({"uid": _param.get("scatuid", None)})
 
-            _scats = self.scats(**_param)
-            _table = "{}:{}".format(self.get_table(
-                type=_type, opt="index"), "scats")
-            for _s in _scats:
-                for _a, _suid in self._redis.zscan_iter(name="{}:{}".format(_table, _s.get("uid")), match="*"):
-                    _uids.append(int(_suid))
-                break
-        _table = "{}:{}:{}".format(self.get_table(
-            type="videos", opt="index"), self._source, "id")
-        _ppl_table = "{}:{}:{}".format(self.get_table(
-            type="people", opt="index"), self._source, "id")
-        _pg = 0 if _page is None else int(_page)
-        _cnt = 50 if _count is None else int(_count)
-        _uids = _uids[(_pg * _cnt):((_pg + 1) * _cnt)]
-        for _v in self._search(type=_type, keyval=_video, id=_videoid,
+            _scats = [_s.get("uid") for _s in self.scats(**_param)]
+            _uids = self._map_uid(
+                type=_type, keycol="scats", uids=_scats[0], usesource=False)
+            if _uids == []:
+                return []
+
+        _uids = self._limit_count(data=_uids, page=_page, count=_count)
+        _title = f"*{_video}*" if _video is not None else _video
+        for _v in self._search(type=_type, keyval=_title, id=_videoid,
                                uid=_uids, page=_page, count=_count):
             _ppl_lst = []
-            for _, _puid in self._redis.zscan_iter(name="{}:{}".format(_ppl_table, _v.get("uid")), match="*"):
-                _p = self.people(uid=int(_puid))
-                if len(_p) > 0:
-                    _ppl_lst += _p
+            for _p in [self.people(uid=_puid) for _puid in self._map_uid(
+                    type="people", keycol="id", uids=_v.get("uid"), usesource=True)]:
+                _ppl_lst += _p
             if len(_ppl_lst) > 0:
+                _ppl_lst = self._output("people", _ppl_lst)
                 _v.update({"people": _ppl_lst})
-            for _, _vuid in self._redis.zscan_iter(name="{}:{}".format(_table, _v.get("uid")), match="*"):
-                for _t in self.tmdb(uid=int(_vuid)):
-                    if _t != {}:
-                        _t.update(
-                            {"{}_uid".format(self._source): _v.get("uid")})
-                        _v.update(_t)
-                        break
+            _tmdb_video = []
+            for _t in [self.tmdb(uid=_tvuid) for _tvuid in self._map_uid(
+                    type="videos", keycol="id", uids=_v.get("uid"), usesource=True)]:
+                if _t == []:
+                    continue
+                _tmdb_video = _t
                 break
+            if len(_tmdb_video) > 0:
+                _tmdb_video = _tmdb_video[0]
+                _tmdb_video.update(
+                    {"{}_uid".format(_type): _v.get("uid")})
+                _v.update(_tmdb_video)
             _rtn.append(_v)
+        return self._output("videos", _rtn)
+
+    def _video_fix_st_ep(self, data: dict) -> dict:
+        _id = data.get("id", None)
+        if _id is None:
+            return data
+        try:
+            _st = int(data.get("st", 1))
+        except:
+            _st = 1
+        try:
+            _ep = int(data.get("ep", 1))
+        except:
+            _ep = 1
+        _rtn = []
+        for _s in range(1, _st + 1):
+            for _e in range(1, _ep + 1):
+                _rtn.append({"st": _s, "ep": _e,
+                             "query": f"vid={_id}&st={_s}&ep={_e}"})
+        if _rtn != []:
+            data.update({"streams": _rtn})
+        return data
+
+    def _video_fix_img(self, data: dict) -> dict:
+        _pfx = "https://image.tmdb.org/t/p/w500"
+        _cols = ["poster_path", "backdrop_path", "profile_path"]
+        for _c in _cols:
+            _v = data.get(_c, None)
+            _val = None
+            if _v is None or _v == "":
+                if _c == "backdrop_path":
+                    continue
+                _val = "https://bit.ly/355Y0kU"
+            else:
+                if _v.startswith("http"):
+                    continue
+                else:
+                    _val = f"{_pfx}{_v}"
+            if _val is not None:
+                data.update({_c: _val})
+        return data
+
+    def _video_fix_year(self, data: dict) -> dict:
+        try:
+            _year = int(data.get("year", ""))
+        except:
+            try:
+                _year = int(data.get("release_date", "")[:4])
+            except:
+                _year = None
+        try:
+            data.pop("year")
+        except:
+            pass
+        if _year is not None:
+            data.update({"year": _year})
+        return data
+
+    def _output(self, type: str, data: list) -> list:
+        _rtn = []
+        _col = {}
+        if type == "videos":
+            _col = {"title": ("title", "original_title"),
+                    "tail": "tail",
+                    "img": ("poster_path", "img", "backdrop_path"),
+                    "backdrop": "backdrop_path",
+                    "year": "year",
+                    "release_date": "release_date",
+                    "overview": "overview",
+                    "tmdb_id": "tmdb_id",
+                    "tmdb_uid": "uid",
+                    "org_title": "original_title",
+                    "lang": "original_language",
+                    "id": "id",
+                    "streams": "streams",
+                    "uid": "imaple_uid",
+                    "people": "people",
+                    }
+        elif type == "people":
+            _col = {"name": ("oth_name", "name", "en_name"),
+                    "img": "profile_path"
+                    }
+        for _d in data:
+            if type == "videos":
+                _d = self._video_fix_year(_d)
+                _d = self._video_fix_img(_d)
+                _d = self._video_fix_st_ep(_d)
+            elif type == "people":
+                _d = self._video_fix_img(_d)
+
+            _ndata = {}
+            for _k, _v in _col.items():
+                if isinstance(_v, tuple):
+                    for _x in _v:
+                        _val = _d.get(_x, None)
+                        if _val is not None:
+                            break
+                else:
+                    _val = _d.get(_v, None)
+                if _val is not None:
+                    _ndata.update({_k: _val})
+            _rtn.append(_ndata)
         return _rtn
